def is_prime(num):
    if num <= 1:
        return False
    elif num == 2:
        return True
    elif num % 2 == 0:
        return False
    else:
        # Check for factors up to the square root of the number
        for i in range(3, int(num**0.5) + 1, 2):
            if num % i == 0:
                return False
        return True



from setuptools import setup, find_packages

setup(
    name='demommath',
    version='0.1.2',
    packages=find_packages(),
    install_requires=[
       'numpy','configparse','struct','os','sys','time','netCDF4' # List your dependencies here
    ],
    entry_points={
        'console_scripts': [
            'your-command-name=your_package.module1:main_function',
        ],
    },
    author='Gangesh',
    author_email='gvelip@nio.org',
    description='This package is for testing And How to create a package',

)




def factorial(n):
    if n < 0:
        raise ValueError("Factorial is not defined for negative numbers.")
    if n == 0 or n == 1:
        return 1

    result = 1
    for i in range(2, n + 1):
        result *= i

    return result


